@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 import json
-from typing import Dict, List
+from typing import Optional
 
 from ..store import DataStore, DataStoreManager
 from ..typedefs import Item
@@ -40,7 +42,7 @@ class bitbankDataStore(DataStoreManager):
 class Transactions(DataStore):
     _MAXLEN = 99999
 
-    def _onmessage(self, room_name: str, data: List[Item]) -> None:
+    def _onmessage(self, room_name: str, data: list[Item]) -> None:
         data = data['transactions']
         for item in data:
             pair = room_name.replace('transactions_', '')
@@ -51,16 +53,18 @@ class Depth(DataStore):
     _KEYS = ['pair', 'side', 'price']
     _BDSIDE = {'sell': 'asks', 'buy': 'bids'}
 
-    def sorted(self, query: Item = {}) -> Dict[str, List[float]]:
+    def sorted(self, query: Optional[Item] = None) -> dict[str, list[float]]:
+        if query is None:
+            query = {}
         result = {'asks': [], 'bids': []}
         for item in self:
             if all(k in item and query[k] == item[k] for k in query):
                 result[self._BDSIDE[item['side']]].append([item['price'], item['size']])
-        result['asks'].sort(key=lambda x: x[0])
-        result['bids'].sort(key=lambda x: x[0], reverse=True)
+        result['asks'].sort(key=lambda x: float(x[0]))
+        result['bids'].sort(key=lambda x: float(x[0]), reverse=True)
         return result
 
-    def _onmessage(self, room_name: str, data: List[Item]) -> None:
+    def _onmessage(self, room_name: str, data: list[Item]) -> None:
         if 'whole' in room_name:
             pair = room_name.replace('depth_whole_', '')
             result = self.find({'pair': pair})
